@@ -85,10 +85,8 @@ static GSList *peers = NULL;
 
 static struct network_peer *find_peer(GSList *list, const char *path)
 {
-	GSList *l;
-
-	for (l = list; l; l = l->next) {
-		struct network_peer *peer = l->data;
+	for (; list; list = list->next) {
+		struct network_peer *peer = list->data;
 
 		if (!strcmp(peer->path, path))
 			return peer;
@@ -99,10 +97,8 @@ static struct network_peer *find_peer(GSList *list, const char *path)
 
 static struct network_conn *find_connection(GSList *list, uint16_t id)
 {
-	GSList *l;
-
-	for (l = list; l; l = l->next) {
-		struct network_conn *nc = l->data;
+	for (; list; list = list->next) {
+		struct network_conn *nc = list->data;
 
 		if (nc->id == id)
 			return nc;
@@ -195,7 +191,7 @@ static gboolean bnep_setup_cb(GIOChannel *chan, GIOCondition cond,
 	struct bnep_control_rsp *rsp;
 	struct timeval timeo;
 	char pkt[BNEP_MTU];
-	gsize r;
+	ssize_t r;
 	int sk;
 	const char *pdev, *uuid;
 	gboolean connected;
@@ -208,21 +204,23 @@ static gboolean bnep_setup_cb(GIOChannel *chan, GIOCondition cond,
 		goto failed;
 	}
 
+	sk = g_io_channel_unix_get_fd(chan);
+
 	memset(pkt, 0, BNEP_MTU);
-	if (g_io_channel_read(chan, pkt, sizeof(pkt) - 1,
-				&r) != G_IO_ERROR_NONE) {
+	r = read(sk, pkt, sizeof(pkt) -1);
+	if (r < 0) {
 		error("IO Channel read error");
 		goto failed;
 	}
 
-	if (r <= 0) {
+	if (r == 0) {
 		error("No packet received on l2cap socket");
 		goto failed;
 	}
 
 	errno = EPROTO;
 
-	if (r < sizeof(*rsp)) {
+	if ((size_t) r < sizeof(*rsp)) {
 		error("Packet received is not bnep type");
 		goto failed;
 	}
@@ -243,8 +241,6 @@ static gboolean bnep_setup_cb(GIOChannel *chan, GIOCondition cond,
 		goto failed;
 	}
 
-	sk = g_io_channel_unix_get_fd(chan);
-
 	memset(&timeo, 0, sizeof(timeo));
 	timeo.tv_sec = 0;
 
@@ -481,8 +477,10 @@ static DBusMessage *connection_get_properties(DBusConnection *conn,
 	return reply;
 }
 
-static void connection_free(struct network_conn *nc)
+static void connection_free(void *data)
 {
+	struct network_conn *nc = data;
+
 	if (nc->dc_id)
 		device_remove_disconnect_watch(nc->peer->device, nc->dc_id);
 
@@ -494,8 +492,7 @@ static void connection_free(struct network_conn *nc)
 
 static void peer_free(struct network_peer *peer)
 {
-	g_slist_foreach(peer->connections, (GFunc) connection_free, NULL);
-	g_slist_free(peer->connections);
+	g_slist_free_full(peer->connections, connection_free);
 	btd_device_unref(peer->device);
 	g_free(peer->path);
 	g_free(peer);
